@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -457,6 +457,10 @@ class CDRule extends CApiService {
 	protected function validateDChecks(array $dchecks) {
 		$uniq = 0;
 		$item_key_parser = new CItemKey();
+		$source_values = [
+			'name_source' => [ZBX_DISCOVERY_UNSPEC, ZBX_DISCOVERY_DNS, ZBX_DISCOVERY_IP, ZBX_DISCOVERY_VALUE],
+			'host_source' => [ZBX_DISCOVERY_DNS, ZBX_DISCOVERY_IP, ZBX_DISCOVERY_VALUE]
+		];
 
 		if (!is_array($dchecks)) {
 			self::exception(ZBX_API_ERROR_PARAMETERS,
@@ -485,6 +489,30 @@ class CDRule extends CApiService {
 				self::exception(ZBX_API_ERROR_PARAMETERS, _s('Incorrect port range.'));
 			}
 
+			foreach ($source_values as $field => $values) {
+				if (!array_key_exists($field, $dcheck)) {
+					continue;
+				}
+
+				if (!in_array($dcheck['type'], [SVC_AGENT, SVC_SNMPv1, SVC_SNMPv2c, SVC_SNMPv3])
+						&& $dcheck[$field] == ZBX_DISCOVERY_VALUE) {
+					self::exception(ZBX_API_ERROR_PARAMETERS,
+						_s('Incorrect value for field "%1$s": %2$s.', $field, $dcheck[$field])
+					);
+				}
+
+				if (!in_array($dcheck[$field], $values)) {
+					self::exception(ZBX_API_ERROR_PARAMETERS,
+						_s('Incorrect value for field "%1$s": %2$s.', $field, $dcheck[$field])
+					);
+				}
+
+				// Only one check can be equal ZBX_DISCOVERY_VALUE for 'host_source' and 'name_source' fields.
+				if ($dcheck[$field] == ZBX_DISCOVERY_VALUE) {
+					array_pop($source_values[$field]);
+				}
+			}
+
 			$dcheck_types = [SVC_SSH, SVC_LDAP, SVC_SMTP, SVC_FTP, SVC_HTTP, SVC_POP, SVC_NNTP, SVC_IMAP, SVC_TCP,
 				SVC_AGENT, SVC_SNMPv1, SVC_SNMPv2c, SVC_ICMPPING, SVC_SNMPv3, SVC_HTTPS, SVC_TELNET
 			];
@@ -710,7 +738,7 @@ class CDRule extends CApiService {
 			'output' => ['druleid', 'proxy_hostid', 'name', 'iprange', 'delay', 'status'],
 			'selectDChecks' => ['dcheckid', 'druleid', 'type', 'key_', 'snmp_community', 'ports', 'snmpv3_securityname',
 				'snmpv3_securitylevel', 'snmpv3_authpassphrase', 'snmpv3_privpassphrase', 'uniq', 'snmpv3_authprotocol',
-				'snmpv3_privprotocol', 'snmpv3_contextname'
+				'snmpv3_privprotocol', 'snmpv3_contextname', 'host_source', 'name_source'
 			],
 			'druleids' => $druleids,
 			'editable' => true,
@@ -896,10 +924,9 @@ class CDRule extends CApiService {
 				]);
 				$dchecks = zbx_toHash($dchecks, 'druleid');
 				foreach ($result as $druleid => $drule) {
-					if (isset($dchecks[$druleid]))
-						$result[$druleid]['dchecks'] = $dchecks[$druleid]['rowscount'];
-					else
-						$result[$druleid]['dchecks'] = 0;
+					$result[$druleid]['dchecks'] = array_key_exists($druleid, $dchecks)
+						? $dchecks[$druleid]['rowscount']
+						: '0';
 				}
 			}
 		}
@@ -926,10 +953,9 @@ class CDRule extends CApiService {
 				]);
 				$dhosts = zbx_toHash($dhosts, 'druleid');
 				foreach ($result as $druleid => $drule) {
-					if (isset($dhosts[$druleid]))
-						$result[$druleid]['dhosts'] = $dhosts[$druleid]['rowscount'];
-					else
-						$result[$druleid]['dhosts'] = 0;
+					$result[$druleid]['dhosts'] = array_key_exists($druleid, $dhosts)
+						? $dhosts[$druleid]['rowscount']
+						: '0';
 				}
 			}
 		}
