@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -269,7 +269,7 @@ class DB {
 		$schema = self::getSchema($table_name);
 
 		if ($schema['fields'][$field_name]['type'] == self::FIELD_TYPE_TEXT) {
-			return ($DB['TYPE'] == ZBX_DB_DB2 || $DB['TYPE'] == ZBX_DB_ORACLE) ? 2048 : 65536;
+			return ($DB['TYPE'] == ZBX_DB_DB2 || $DB['TYPE'] == ZBX_DB_ORACLE) ? 2048 : 65535;
 		}
 
 		return $schema['fields'][$field_name]['length'];
@@ -850,24 +850,6 @@ class DB {
 		return true;
 	}
 
-	/**
-	 * Check if $type is numeric field type.
-	 *
-	 * @param int $type
-	 *
-	 * @return bool
-	 */
-	public static function isNumericFieldType($type) {
-		switch ($type) {
-			case self::FIELD_TYPE_ID:
-			case self::FIELD_TYPE_INT:
-			case self::FIELD_TYPE_UINT:
-				return true;
-		}
-
-		return false;
-	}
-
 	/**
 	 * @param string $table_name
 	 * @param array  $options
@@ -1045,10 +1027,21 @@ class DB {
 			}
 
 			$field_schema = $table_schema['fields'][$pk];
+			$field_name = self::fieldId($pk, $table_alias);
 
-			$sql_parts['where'][] = self::isNumericFieldType($field_schema['type'])
-				? dbConditionInt(self::fieldId($pk, $table_alias), $options[$pk_option], false, true, false)
-				: dbConditionString(self::fieldId($pk, $table_alias), $options[$pk_option]);
+			switch ($field_schema['type']) {
+				case self::FIELD_TYPE_ID:
+					$sql_parts['where'][] = dbConditionId($field_name, $options[$pk_option]);
+					break;
+
+				case self::FIELD_TYPE_INT:
+				case self::FIELD_TYPE_UINT:
+					$sql_parts['where'][] = dbConditionInt($field_name, $options[$pk_option]);
+					break;
+
+				default:
+					$sql_parts['where'][] = dbConditionString($field_name, $options[$pk_option]);
+			}
 		}
 
 		// filters
@@ -1096,9 +1089,19 @@ class DB {
 				$value = [$value];
 			}
 
-			$filter[] = self::isNumericFieldType($field_schema['type'])
-				? dbConditionInt(self::fieldId($field_name, $table_alias), $value, false, true, false)
-				: dbConditionString(self::fieldId($field_name, $table_alias), $value);
+			switch ($field_schema['type']) {
+				case self::FIELD_TYPE_ID:
+					$filter[] = dbConditionId(self::fieldId($field_name, $table_alias), $value);
+					break;
+
+				case self::FIELD_TYPE_INT:
+				case self::FIELD_TYPE_UINT:
+					$filter[] = dbConditionInt(self::fieldId($field_name, $table_alias), $value);
+					break;
+
+				default:
+					$filter[] = dbConditionString(self::fieldId($field_name, $table_alias), $value);
+			}
 		}
 
 		if ($filter) {
