@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,6 +20,10 @@
 
 
 class CMultiSelect extends CTag {
+	/**
+	 * Default CSS class name for HTML root element.
+	 */
+	const ZBX_STYLE_CLASS = 'multiselect-control';
 
 	/**
 	 * @param array $options['objectOptions']  An array of parameters to be added to the request URL.
@@ -172,9 +176,10 @@ class CMultiSelect extends CTag {
 				$parameters = $options['popup']['parameters'];
 
 				$valid_fields = ['srctbl', 'srcfld1', 'srcfld2', 'dstfrm', 'dstfld1', 'real_hosts', 'monitored_hosts',
-					'with_monitored_triggers', 'noempty', 'editable', 'templated_hosts', 'hostid', 'webitems',
-					'normal_only', 'numeric', 'with_simple_graph_items', 'with_triggers', 'value_types', 'excludeids',
-					'disableids', 'enrich_parent_groups'];
+					'with_monitored_triggers', 'noempty', 'editable', 'templated_hosts', 'hostid', 'parent_discoveryid',
+					'webitems', 'normal_only', 'numeric', 'with_simple_graph_items', 'with_triggers', 'value_types',
+					'excludeids', 'disableids', 'enrich_parent_groups'
+				];
 
 				foreach ($parameters as $field => $value) {
 					if (!in_array($field, $valid_fields)) {
@@ -201,8 +206,13 @@ class CMultiSelect extends CTag {
 				}
 
 				if (array_key_exists('hostid', $parameters) && $parameters['hostid'] > 0) {
-					$popup_parameters['only_hostid'] = $parameters['hostid'];
-					$autocomplete_parameters['hostid'] = $parameters['hostid'];
+					$popup_parameters['only_hostid'] = (string) $parameters['hostid'];
+					$autocomplete_parameters['hostid'] = (string) $parameters['hostid'];
+				}
+
+				if (array_key_exists('parent_discoveryid', $parameters) && $parameters['parent_discoveryid'] > 0) {
+					$popup_parameters['parent_discoveryid'] = $parameters['parent_discoveryid'];
+					$autocomplete_parameters['parent_discoveryid'] = $parameters['parent_discoveryid'];
 				}
 
 				if (array_key_exists('numeric', $parameters) && $parameters['numeric']) {
